namespace efl { namespace image { 
inline ::efl::eolian::return_traits<void>::type Load::load_size_get( ::efl::eolian::out_traits<int>::type w,  ::efl::eolian::out_traits<int>::type h) const
{
   int __out_param_w = {};
   int __out_param_h = {};
    ::efl_image_load_size_get(this->_eo_ptr()
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(h, __out_param_h);
}
inline ::efl::eolian::return_traits<void>::type Load::load_size_set( ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h) const
{
    ::efl_image_load_size_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h));
}
inline ::efl::eolian::return_traits<double>::type Load::load_dpi_get() const
{
   double __return_value =  ::efl_image_load_dpi_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Load::load_dpi_set( ::efl::eolian::in_traits<double>::type dpi) const
{
    ::efl_image_load_dpi_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(dpi));
}
inline ::efl::eolian::return_traits<bool>::type Load::load_region_support_get() const
{
   Eina_Bool __return_value =  ::efl_image_load_region_support_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Load::load_region_get( ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y,  ::efl::eolian::out_traits<int>::type w,  ::efl::eolian::out_traits<int>::type h) const
{
   int __out_param_x = {};
   int __out_param_y = {};
   int __out_param_w = {};
   int __out_param_h = {};
    ::efl_image_load_region_get(this->_eo_ptr()
      , & __out_param_x
      , & __out_param_y
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(h, __out_param_h);
}
inline ::efl::eolian::return_traits<void>::type Load::load_region_set( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h) const
{
    ::efl_image_load_region_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h));
}
inline ::efl::eolian::return_traits<bool>::type Load::load_orientation_get() const
{
   Eina_Bool __return_value =  ::efl_image_load_orientation_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Load::load_orientation_set( ::efl::eolian::in_traits<bool>::type enable) const
{
    ::efl_image_load_orientation_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(enable));
}
inline ::efl::eolian::return_traits<int>::type Load::load_scale_down_get() const
{
   int __return_value =  ::efl_image_load_scale_down_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Load::load_scale_down_set( ::efl::eolian::in_traits<int>::type div) const
{
    ::efl_image_load_scale_down_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(div));
}
inline ::efl::eolian::return_traits<Efl_Image_Load_Error>::type Load::load_error_get() const
{
   Efl_Image_Load_Error __return_value =  ::efl_image_load_error_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Image_Load_Error>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Load::load_async_start() const
{
    ::efl_image_load_async_start(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Load::load_async_cancel() const
{
    ::efl_image_load_async_cancel(this->_eo_ptr());
}
} } 
namespace eo_cxx {
namespace efl { namespace image { 
inline ::efl::eolian::return_traits<void>::type Load::load_size_get( ::efl::eolian::out_traits<int>::type w,  ::efl::eolian::out_traits<int>::type h) const
{
   int __out_param_w = {};
   int __out_param_h = {};
    ::efl_image_load_size_get(this->_eo_ptr()
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(h, __out_param_h);
}
inline ::efl::eolian::return_traits<void>::type Load::load_size_set( ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h) const
{
    ::efl_image_load_size_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h));
}
inline ::efl::eolian::return_traits<double>::type Load::load_dpi_get() const
{
   double __return_value =  ::efl_image_load_dpi_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Load::load_dpi_set( ::efl::eolian::in_traits<double>::type dpi) const
{
    ::efl_image_load_dpi_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(dpi));
}
inline ::efl::eolian::return_traits<bool>::type Load::load_region_support_get() const
{
   Eina_Bool __return_value =  ::efl_image_load_region_support_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Load::load_region_get( ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y,  ::efl::eolian::out_traits<int>::type w,  ::efl::eolian::out_traits<int>::type h) const
{
   int __out_param_x = {};
   int __out_param_y = {};
   int __out_param_w = {};
   int __out_param_h = {};
    ::efl_image_load_region_get(this->_eo_ptr()
      , & __out_param_x
      , & __out_param_y
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(h, __out_param_h);
}
inline ::efl::eolian::return_traits<void>::type Load::load_region_set( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h) const
{
    ::efl_image_load_region_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h));
}
inline ::efl::eolian::return_traits<bool>::type Load::load_orientation_get() const
{
   Eina_Bool __return_value =  ::efl_image_load_orientation_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Load::load_orientation_set( ::efl::eolian::in_traits<bool>::type enable) const
{
    ::efl_image_load_orientation_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(enable));
}
inline ::efl::eolian::return_traits<int>::type Load::load_scale_down_get() const
{
   int __return_value =  ::efl_image_load_scale_down_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Load::load_scale_down_set( ::efl::eolian::in_traits<int>::type div) const
{
    ::efl_image_load_scale_down_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(div));
}
inline ::efl::eolian::return_traits<Efl_Image_Load_Error>::type Load::load_error_get() const
{
   Efl_Image_Load_Error __return_value =  ::efl_image_load_error_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Image_Load_Error>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Load::load_async_start() const
{
    ::efl_image_load_async_start(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Load::load_async_cancel() const
{
    ::efl_image_load_async_cancel(this->_eo_ptr());
}
inline efl::image::Load::operator ::efl::image::Load() const { return *static_cast< ::efl::image::Load const*>(static_cast<void const*>(this)); }
inline efl::image::Load::operator ::efl::image::Load&() { return *static_cast< ::efl::image::Load*>(static_cast<void*>(this)); }
inline efl::image::Load::operator ::efl::image::Load const&() const { return *static_cast< ::efl::image::Load const*>(static_cast<void const*>(this)); }
} } }

